==> ws-v3.70.10-src.tar.gz: ws-v3.70-10/include/WSCsheetdef.h <==
#ifndef _WSCSHEETDEF_H
#define _WSCSHEETDEF_H

#ifndef MSW
#define       WSNrows                  _WSNrows
extern char* _WSNrows;
#define       WSNcols                  _WSNcols
extern char* _WSNcols;
#define       WSNfixedRows             _WSNfixedRows
extern char* _WSNfixedRows;
#define       WSNfixedCols             _WSNfixedCols
extern char* _WSNfixedCols;
#define       WSNgridLines             _WSNgridLines
extern char* _WSNgridLines;
#define       WSNcellDefWidth          _WSNcellDefWidth
extern char* _WSNcellDefWidth;
#define       WSNcellDefHeight         _WSNcellDefHeight
extern char* _WSNcellDefHeight;
#define       WSNfixedColHeight        _WSNfixedColHeight
extern char* _WSNfixedColHeight;
#define       WSNcellDefFont           _WSNcellDefFont
extern char* _WSNcellDefFont;
#define       WSNfixedCellFont         _WSNfixedCellFont
extern char* _WSNfixedCellFont;
#define       WSNeditEnabled           _WSNeditEnabled
extern char* _WSNeditEnabled;
#define       WSNhautoNumber           _WSNhautoNumber
extern char* _WSNhautoNumber;
#define       WSNvautoNumber           _WSNvautoNumber
extern char* _WSNvautoNumber;
#define       WSNsheetBackColor        _WSNsheetBackColor
extern char* _WSNsheetBackColor;
#define       WSNcellDefBackColor      _WSNcellDefBackColor
extern char* _WSNcellDefBackColor;
#define       WSNcellDefTextColor      _WSNcellDefTextColor
extern char* _WSNcellDefTextColor;
#define       WSNfixedBackColor        _WSNfixedBackColor
extern char* _WSNfixedBackColor;
#define       WSNfixedTextColor        _WSNfixedTextColor
extern char* _WSNfixedTextColor;
#define       WSNgridColor             _WSNgridColor
extern char* _WSNgridColor;
#define       WSNdbItem                _WSNdbItem
extern char* _WSNdbItem;
#define       WSNsortItem1             _WSNsortItem1
extern char* _WSNsortItem1;
#define       WSNsort1                 _WSNsort1
extern char* _WSNsort1;
#define       WSNsortItem2             _WSNsortItem2
extern char* _WSNsortItem2;
#define       WSNsort2                 _WSNsort2
extern char* _WSNsort2;
#define       WSNsortItem3             _WSNsortItem2
extern char* _WSNsortItem3;
#define       WSNsort3                 _WSNsort3
extern char* _WSNsort3;
//#define       WSNfilter                _WSNfilter
//extern char* _WSNfilter;
#define       WSNsql                   _WSNsql
extern char* _WSNsql;
#define       WSNdbCellAutoResize      _WSNdbCellAutoResize
extern char* _WSNdbCellAutoResize;
#define       WSNdbCellTitle           _WSNdbCellTitle
extern char* _WSNdbCellTitle;

#else //MSW

#define       WSNrows                  _WSNrows()
extern char* _WSNrows();
#define       WSNcols                  _WSNcols()
extern char* _WSNcols();
#define       WSNfixedRows             _WSNfixedRows()
extern char* _WSNfixedRows();
#define       WSNfixedCols             _WSNfixedCols()
extern char* _WSNfixedCols();
#define       WSNgridLines             _WSNgridLines()
extern char* _WSNgridLines();
#define       WSNcellDefWidth          _WSNcellDefWidth()
extern char* _WSNcellDefWidth();
#define       WSNcellDefHeight         _WSNcellDefHeight()
extern char* _WSNcellDefHeight();
#define       WSNfixedColHeight        _WSNfixedColHeight()
extern char* _WSNfixedColHeight();
#define       WSNcellDefFont           _WSNcellDefFont()
extern char* _WSNcellDefFont();
#define       WSNfixedCellFont         _WSNfixedCellFont()
extern char* _WSNfixedCellFont();
#define       WSNeditEnabled           _WSNeditEnabled()
extern char* _WSNeditEnabled();
#define       WSNhautoNumber           _WSNhautoNumber()
extern char* _WSNhautoNumber();
#define       WSNvautoNumber           _WSNvautoNumber()
extern char* _WSNvautoNumber();
#define       WSNsheetBackColor        _WSNsheetBackColor()
extern char* _WSNsheetBackColor();
#define       WSNcellDefBackColor      _WSNcellDefBackColor()
extern char* _WSNcellDefBackColor();
#define       WSNcellDefTextColor      _WSNcellDefTextColor()
extern char* _WSNcellDefTextColor();
#define       WSNfixedBackColor        _WSNfixedBackColor()
extern char* _WSNfixedBackColor();
#define       WSNfixedTextColor        _WSNfixedTextColor()
extern char* _WSNfixedTextColor();
#define       WSNgridColor             _WSNgridColor()
extern char* _WSNgridColor();
#define       WSNdbItem                _WSNdbItem()
extern char* _WSNdbItem();
#define       WSNsortItem1             _WSNsortItem1()
extern char* _WSNsortItem1();
#define       WSNsort1                 _WSNsort1()
extern char* _WSNsort1();
#define       WSNsortItem2             _WSNsortItem2()
extern char* _WSNsortItem2();
#define       WSNsort2                 _WSNsort2()
extern char* _WSNsort2();
#define       WSNsortItem3             _WSNsortItem2()
extern char* _WSNsortItem3();
#define       WSNsort3                 _WSNsort3()
extern char* _WSNsort3();
//#define       WSNfilter                _WSNfilter()
//extern char* _WSNfilter();
#define       WSNsql                   _WSNsql()
extern char* _WSNsql();
#define       WSNdbCellAutoResize      _WSNdbCellAutoResize()
extern char* _WSNdbCellAutoResize();
#define       WSNdbCellTitle           _WSNdbCellTitle()
extern char* _WSNdbCellTitle();


#endif

extern char** _WSRsort1();
#define  WSRsort1 _WSRsort1()
extern char** _WSRsort1D();
#define  WSRsort1D _WSRsort1D()
extern char** _WSRsort2();
#define  WSRsort2 _WSRsort2()
extern char** _WSRsort2D();
#define  WSRsort2D _WSRsort2D()
extern char** _WSRsort3();
#define  WSRsort3 _WSRsort3()
extern char** _WSRsort3D();
#define  WSRsort3D _WSRsort3D()

extern char** _WSRgridLines();
#define  WSRgridLines _WSRgridLines()
extern char** _WSRgridLinesD();
#define  WSRgridLinesD _WSRgridLinesD()


#define WSSrows             _WSSrows()
#define WSScols             _WSScols()
#define WSSfixedRows        _WSSfixedRows()
#define WSSfixedCols        _WSSfixedCols()
#define WSSgridLines        _WSSgridLines()
#define WSScellDefWidth     _WSScellDefWidth()
#define WSScellDefHeight    _WSScellDefHeight()
#define WSSfixedColHeight   _WSSfixedColHeight()
#define WSScellDefFont      _WSScellDefFont()
#define WSSfixedCellFont    _WSSfixedCellFont()
#define WSSeditEnabled      _WSSeditEnabled()
#define WSShautoNumber      _WSShautoNumber()
#define WSSvautoNumber      _WSSvautoNumber()
#define WSSsheetBackColor   _WSSsheetBackColor()
#define WSScellDefBackColor _WSScellDefBackColor()
#define WSScellDefTextColor _WSScellDefTextColor()
#define WSSfixedBackColor   _WSSfixedBackColor()
#define WSSfixedTextColor   _WSSfixedTextColor()
#define WSSgridColor        _WSSgridColor()
#define WSSdbitem           _WSSdbitem()
#define WSSsortItem1        _WSSsortItem1()
#define WSSsort1            _WSSsort1()
#define WSSsortItem2        _WSSsortItem2()
#define WSSsort2            _WSSsort2()
#define WSSsortItem3        _WSSsortItem3()
#define WSSsort3            _WSSsort3()
#define WSSsql              _WSSsql()
#define WSSdbCellAutoResize _WSSdbCellAutoResize()
#define WSSdbCellTitle      _WSSdbCellTitle()


extern char* _WSSrows();
extern char* _WSScols();
extern char* _WSSfixedRows();
extern char* _WSSfixedCols();
extern char* _WSSgridLines();
extern char* _WSScellDefWidth();
extern char* _WSScellDefHeight();
extern char* _WSSfixedColHeight();
extern char* _WSScellDefFont();
extern char* _WSSfixedCellFont();
extern char* _WSSeditEnabled();
extern char* _WSShautoNumber();
extern char* _WSSvautoNumber();
extern char* _WSSsheetBackColor();
extern char* _WSScellDefBackColor();
extern char* _WSScellDefTextColor();
extern char* _WSSfixedBackColor();
extern char* _WSSfixedTextColor();
extern char* _WSSgridColor();
extern char* _WSSdbitem();
extern char* _WSSsortItem1();
extern char* _WSSsort1();
extern char* _WSSsortItem2();
extern char* _WSSsort2();
extern char* _WSSsortItem3();
extern char* _WSSsort3();
extern char* _WSSsql();
extern char* _WSSdbCellAutoResize();
extern char* _WSSdbCellTitle();

#endif // _WSCSHEETDEF_H

==> ws-v3.80.5-src.tar.gz: ws-v3.80-5/include/WSCsheetdef.h <==
#ifndef _WSCSHEETDEF_H
#define _WSCSHEETDEF_H

#ifndef MSW
#define       WSNrows                  _WSNrows
extern char* _WSNrows;
#define       WSNcols                  _WSNcols
extern char* _WSNcols;
#define       WSNfixedRows             _WSNfixedRows
extern char* _WSNfixedRows;
#define       WSNfixedCols             _WSNfixedCols
extern char* _WSNfixedCols;
#define       WSNgridLines             _WSNgridLines
extern char* _WSNgridLines;
#define       WSNcellDefWidth          _WSNcellDefWidth
extern char* _WSNcellDefWidth;
#define       WSNcellDefHeight         _WSNcellDefHeight
extern char* _WSNcellDefHeight;
#define       WSNfixedColHeight        _WSNfixedColHeight
extern char* _WSNfixedColHeight;
#define       WSNcellDefFont           _WSNcellDefFont
extern char* _WSNcellDefFont;
#define       WSNfixedCellFont         _WSNfixedCellFont
extern char* _WSNfixedCellFont;
#define       WSNeditEnabled           _WSNeditEnabled
extern char* _WSNeditEnabled;
#define       WSNhautoNumber           _WSNhautoNumber
extern char* _WSNhautoNumber;
#define       WSNvautoNumber           _WSNvautoNumber
extern char* _WSNvautoNumber;
#define       WSNsheetBackColor        _WSNsheetBackColor
extern char* _WSNsheetBackColor;
#define       WSNcellDefBackColor      _WSNcellDefBackColor
extern char* _WSNcellDefBackColor;
#define       WSNcellDefTextColor      _WSNcellDefTextColor
extern char* _WSNcellDefTextColor;
#define       WSNfixedBackColor        _WSNfixedBackColor
extern char* _WSNfixedBackColor;
#define       WSNfixedTextColor        _WSNfixedTextColor
extern char* _WSNfixedTextColor;
#define       WSNgridColor             _WSNgridColor
extern char* _WSNgridColor;
#define       WSNdbItem                _WSNdbItem
extern char* _WSNdbItem;
#define       WSNsortItem1             _WSNsortItem1
extern char* _WSNsortItem1;
#define       WSNsort1                 _WSNsort1
extern char* _WSNsort1;
#define       WSNsortItem2             _WSNsortItem2
extern char* _WSNsortItem2;
#define       WSNsort2                 _WSNsort2
extern char* _WSNsort2;
#define       WSNsortItem3             _WSNsortItem2
extern char* _WSNsortItem3;
#define       WSNsort3                 _WSNsort3
extern char* _WSNsort3;
//#define       WSNfilter                _WSNfilter
//extern char* _WSNfilter;
#define       WSNsql                   _WSNsql
extern char* _WSNsql;
#define       WSNdbCellAutoResize      _WSNdbCellAutoResize
extern char* _WSNdbCellAutoResize;
#define       WSNdbCellTitle           _WSNdbCellTitle
extern char* _WSNdbCellTitle;

#else //MSW

#define       WSNrows                  _WSNrows()
extern WSDLEX32 char* _WSNrows();
#define       WSNcols                  _WSNcols()
extern WSDLEX32 char* _WSNcols();
#define       WSNfixedRows             _WSNfixedRows()
extern WSDLEX32 char* _WSNfixedRows();
#define       WSNfixedCols             _WSNfixedCols()
extern WSDLEX32 char* _WSNfixedCols();
#define       WSNgridLines             _WSNgridLines()
extern WSDLEX32 char* _WSNgridLines();
#define       WSNcellDefWidth          _WSNcellDefWidth()
extern WSDLEX32 char* _WSNcellDefWidth();
#define       WSNcellDefHeight         _WSNcellDefHeight()
extern WSDLEX32 char* _WSNcellDefHeight();
#define       WSNfixedColHeight        _WSNfixedColHeight()
extern WSDLEX32 char* _WSNfixedColHeight();
#define       WSNcellDefFont           _WSNcellDefFont()
extern WSDLEX32 char* _WSNcellDefFont();
#define       WSNfixedCellFont         _WSNfixedCellFont()
extern WSDLEX32 char* _WSNfixedCellFont();
#define       WSNeditEnabled           _WSNeditEnabled()
extern WSDLEX32 char* _WSNeditEnabled();
#define       WSNhautoNumber           _WSNhautoNumber()
extern WSDLEX32 char* _WSNhautoNumber();
#define       WSNvautoNumber           _WSNvautoNumber()
extern WSDLEX32 char* _WSNvautoNumber();
#define       WSNsheetBackColor        _WSNsheetBackColor()
extern WSDLEX32 char* _WSNsheetBackColor();
#define       WSNcellDefBackColor      _WSNcellDefBackColor()
extern WSDLEX32 char* _WSNcellDefBackColor();
#define       WSNcellDefTextColor      _WSNcellDefTextColor()
extern WSDLEX32 char* _WSNcellDefTextColor();
#define       WSNfixedBackColor        _WSNfixedBackColor()
extern WSDLEX32 char* _WSNfixedBackColor();
#define       WSNfixedTextColor        _WSNfixedTextColor()
extern WSDLEX32 char* _WSNfixedTextColor();
#define       WSNgridColor             _WSNgridColor()
extern WSDLEX32 char* _WSNgridColor();
#define       WSNdbItem                _WSNdbItem()
extern WSDLEX32 char* _WSNdbItem();
#define       WSNsortItem1             _WSNsortItem1()
extern WSDLEX32 char* _WSNsortItem1();
#define       WSNsort1                 _WSNsort1()
extern WSDLEX32 char* _WSNsort1();
#define       WSNsortItem2             _WSNsortItem2()
extern WSDLEX32 char* _WSNsortItem2();
#define       WSNsort2                 _WSNsort2()
extern WSDLEX32 char* _WSNsort2();
#define       WSNsortItem3             _WSNsortItem2()
extern WSDLEX32 char* _WSNsortItem3();
#define       WSNsort3                 _WSNsort3()
extern WSDLEX32 char* _WSNsort3();
//#define       WSNfilter                _WSNfilter()
//extern WSDLEX32 char* _WSNfilter();
#define       WSNsql                   _WSNsql()
extern WSDLEX32 char* _WSNsql();
#define       WSNdbCellAutoResize      _WSNdbCellAutoResize()
extern WSDLEX32 char* _WSNdbCellAutoResize();
#define       WSNdbCellTitle           _WSNdbCellTitle()
extern WSDLEX32 char* _WSNdbCellTitle();


#endif

extern WSDLEX32 char** _WSRsort1();
#define  WSRsort1 _WSRsort1()
extern WSDLEX32 char** _WSRsort1D();
#define  WSRsort1D _WSRsort1D()
extern WSDLEX32 char** _WSRsort2();
#define  WSRsort2 _WSRsort2()
extern WSDLEX32 char** _WSRsort2D();
#define  WSRsort2D _WSRsort2D()
extern WSDLEX32 char** _WSRsort3();
#define  WSRsort3 _WSRsort3()
extern WSDLEX32 char** _WSRsort3D();
#define  WSRsort3D _WSRsort3D()

extern WSDLEX32 char** _WSRgridLines();
#define  WSRgridLines _WSRgridLines()
extern WSDLEX32 char** _WSRgridLinesD();
#define  WSRgridLinesD _WSRgridLinesD()


#define WSSrows             _WSSrows()
#define WSScols             _WSScols()
#define WSSfixedRows        _WSSfixedRows()
#define WSSfixedCols        _WSSfixedCols()
#define WSSgridLines        _WSSgridLines()
#define WSScellDefWidth     _WSScellDefWidth()
#define WSScellDefHeight    _WSScellDefHeight()
#define WSSfixedColHeight   _WSSfixedColHeight()
#define WSScellDefFont      _WSScellDefFont()
#define WSSfixedCellFont    _WSSfixedCellFont()
#define WSSeditEnabled      _WSSeditEnabled()
#define WSShautoNumber      _WSShautoNumber()
#define WSSvautoNumber      _WSSvautoNumber()
#define WSSsheetBackColor   _WSSsheetBackColor()
#define WSScellDefBackColor _WSScellDefBackColor()
#define WSScellDefTextColor _WSScellDefTextColor()
#define WSSfixedBackColor   _WSSfixedBackColor()
#define WSSfixedTextColor   _WSSfixedTextColor()
#define WSSgridColor        _WSSgridColor()
#define WSSdbitem           _WSSdbitem()
#define WSSsortItem1        _WSSsortItem1()
#define WSSsort1            _WSSsort1()
#define WSSsortItem2        _WSSsortItem2()
#define WSSsort2            _WSSsort2()
#define WSSsortItem3        _WSSsortItem3()
#define WSSsort3            _WSSsort3()
#define WSSsql              _WSSsql()
#define WSSdbCellAutoResize _WSSdbCellAutoResize()
#define WSSdbCellTitle      _WSSdbCellTitle()


extern WSDLEX32 char* _WSSrows();
extern WSDLEX32 char* _WSScols();
extern WSDLEX32 char* _WSSfixedRows();
extern WSDLEX32 char* _WSSfixedCols();
extern WSDLEX32 char* _WSSgridLines();
extern WSDLEX32 char* _WSScellDefWidth();
extern WSDLEX32 char* _WSScellDefHeight();
extern WSDLEX32 char* _WSSfixedColHeight();
extern WSDLEX32 char* _WSScellDefFont();
extern WSDLEX32 char* _WSSfixedCellFont();
extern WSDLEX32 char* _WSSeditEnabled();
extern WSDLEX32 char* _WSShautoNumber();
extern WSDLEX32 char* _WSSvautoNumber();
extern WSDLEX32 char* _WSSsheetBackColor();
extern WSDLEX32 char* _WSScellDefBackColor();
extern WSDLEX32 char* _WSScellDefTextColor();
extern WSDLEX32 char* _WSSfixedBackColor();
extern WSDLEX32 char* _WSSfixedTextColor();
extern WSDLEX32 char* _WSSgridColor();
extern WSDLEX32 char* _WSSdbitem();
extern WSDLEX32 char* _WSSsortItem1();
extern WSDLEX32 char* _WSSsort1();
extern WSDLEX32 char* _WSSsortItem2();
extern WSDLEX32 char* _WSSsort2();
extern WSDLEX32 char* _WSSsortItem3();
extern WSDLEX32 char* _WSSsort3();
extern WSDLEX32 char* _WSSsql();
extern WSDLEX32 char* _WSSdbCellAutoResize();
extern WSDLEX32 char* _WSSdbCellTitle();

#endif // _WSCSHEETDEF_H
